| %<-% | R Documentation |
consign pipe allows destructing data into multiple variables at once.
Internally rlang::set_names is used to name the RHS elements to current
scope.
vars %<-% data
vars |
[R names] Valid R names separated by colon. |
data |
[object] R object of the same length as the number of |
Nothing. Assigns LHS names to current scope.
Other result assemblers:
%$>%(),
%->%(),
%to%(),
conserve(),
control()
val1 : val_2 : someval %<-% c(2, 4, 9) c(val1, val_2, someval) x:y:z %<-% list(c(4,5,12), TRUE, list(a=5,b=9)) x; y; z
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.